** Example of conditional logic in a DATA step program;
data newheight;
  set sashelp.class;
  where age ge 13;
  if sex = 'M' then projected_height=height*1.10;
  else if sex = 'F' then projected_height=height*1.075;
run;

data newhw;
  set sashelp.class;
  where age ge 13;
  if sex = 'M' then do;
     projected_height=height*1.10;
     projected_weight=weight*1.10;
  end;
  else if sex = 'F' then do;
    projected_height=height*1.075;
    projected_weight=weight*1.125;
  end;
run;

ods listing close;
ods html file='c:\temp\demo4_data_logic.html' style=sasweb;
proc report data=newheight nowd;
  title 'Projected Heights for Teenagers';
  footnote 'Boys projected at 10%. Girls projected at 7.5%';
  column sex name age height projected_height;
  define sex / order;
  define name / order;
  define projected_height / 'Projected Height' f=6.2;
run;
   
proc report data=newhw nowd;
  title 'Projected Heights and Weights for Teenagers';
  footnote 'Heights: Boys at 10%. Girls at 7.5%';
  footnote2 'Weights: Boys at 10%. Girls at 12.5%';
  column sex name age height weight projected_height projected_weight;
  define sex / order;
  define name / order;
  define projected_height / 'Projected Height' f=6.2;
  define projected_weight / 'Projected Weight' f=7.2;
run;
ods html close;
title; footnote; 


** Example Macro %IF in open code will generate error message in log;
%let lib=sashelp;
%let data = class;

%if &lib = sashelp and &data = class %then %let numobs = 19;
%else %let numobs = 5;

ods html file='c:\temp\report.html'
    style=sasweb;
  proc print data=&lib..&data(obs=&numobs);
    title "%upcase(&lib..&data): Obs=&numobs";
  run;
     
  ods select attributes variables sortedby;
  proc contents data=&lib..&data;
    title "Documentation for: %sysfunc(propcase(&lib..&data))";
  run;
ods html close;

